@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -22,7 +24,7 @@ class AmsDetailInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 标签
         :type Label: list of str
         :param Duration: 时长(秒/s)
@@ -87,6 +89,13 @@ class AmsDetailInfo(AbstractModel):
         self.DetailCount = params.get("DetailCount")
         self.RequestId = params.get("RequestId")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AudioResult(AbstractModel):
@@ -95,7 +104,7 @@ class AudioResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param HitFlag: 是否命中
 0 未命中
 1 命中
@@ -169,6 +178,13 @@ class AudioResult(AbstractModel):
                 obj = AudioResultDetailLanguageResult()
                 obj._deserialize(item)
                 self.LanguageResults.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AudioResultDetailLanguageResult(AbstractModel):
@@ -177,7 +193,7 @@ class AudioResultDetailLanguageResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 语言信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -207,6 +223,13 @@ class AudioResultDetailLanguageResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AudioResultDetailMoanResult(AbstractModel):
@@ -215,7 +238,7 @@ class AudioResultDetailMoanResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 固定为Moan（呻吟）
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -241,6 +264,13 @@ class AudioResultDetailMoanResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AudioResultDetailTextResult(AbstractModel):
@@ -249,7 +279,7 @@ class AudioResultDetailTextResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 标签
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
@@ -288,6 +318,13 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = params.get("Score")
         self.Suggestion = params.get("Suggestion")
         self.LibType = params.get("LibType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AudioSegments(AbstractModel):
@@ -296,7 +333,7 @@ class AudioSegments(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OffsetTime: 截帧时间。
 点播文件：该值为相对于视频偏移时间，单位为秒，例如：0，5，10
 直播流：该值为时间戳，例如：1594650717
@@ -315,6 +352,13 @@ class AudioSegments(AbstractModel):
         if params.get("Result") is not None:
             self.Result = AudioResult()
             self.Result._deserialize(params.get("Result"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BucketInfo(AbstractModel):
@@ -324,7 +368,7 @@ class BucketInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Bucket: 腾讯云对象存储，存储桶名称
         :type Bucket: str
         :param Region: 地域
@@ -341,6 +385,13 @@ class BucketInfo(AbstractModel):
         self.Bucket = params.get("Bucket")
         self.Region = params.get("Region")
         self.Object = params.get("Object")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelTaskRequest(AbstractModel):
@@ -349,7 +400,7 @@ class CancelTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 任务ID
         :type TaskId: str
         """
@@ -358,6 +409,13 @@ class CancelTaskRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelTaskResponse(AbstractModel):
@@ -366,7 +424,7 @@ class CancelTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -383,7 +441,7 @@ class CreateAudioModerationTaskRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 业务类型, 定义 模版策略，输出存储配置。如果没有BizType，可以先参考 【创建业务配置】接口进行创建
         :type BizType: str
         :param Type: 审核类型，这里可选：AUDIO (点播音频)和 LIVE_AUDIO（直播音频）
@@ -413,6 +471,13 @@ class CreateAudioModerationTaskRequest(AbstractModel):
                 obj = TaskInput()
                 obj._deserialize(item)
                 self.Tasks.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateAudioModerationTaskResponse(AbstractModel):
@@ -421,7 +486,7 @@ class CreateAudioModerationTaskResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Results: 任务创建结果
 注意：此字段可能返回 null，表示取不到有效值。
         :type Results: list of TaskResult
@@ -448,7 +513,7 @@ class CreateBizConfigRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 业务类型，仅限英文字母、数字和下划线（_）组成，长度不超过8位
         :type BizType: str
         :param MediaModeration: 配置信息，
@@ -471,6 +536,13 @@ class CreateBizConfigRequest(AbstractModel):
             self.MediaModeration._deserialize(params.get("MediaModeration"))
         self.BizName = params.get("BizName")
         self.ModerationCategories = params.get("ModerationCategories")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateBizConfigResponse(AbstractModel):
@@ -479,7 +551,7 @@ class CreateBizConfigResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -496,7 +568,7 @@ class DescribeAmsListRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PageToken: 页码
         :type PageToken: str
         :param Limit: 过滤条件
@@ -522,6 +594,13 @@ class DescribeAmsListRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAmsListResponse(AbstractModel):
@@ -530,7 +609,7 @@ class DescribeAmsListResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AmsDetailSet: 返回列表数据----非必选，该参数暂未对外开放
         :type AmsDetailSet: list of AmsDetailInfo
         :param Total: 总条数
@@ -564,7 +643,7 @@ class DescribeAudioStatRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AuditType: 审核类型 1: 机器审核; 2: 人工审核
         :type AuditType: int
         :param Filters: 查询条件
@@ -582,6 +661,13 @@ class DescribeAudioStatRequest(AbstractModel):
                 obj = Filters()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAudioStatResponse(AbstractModel):
@@ -590,7 +676,7 @@ class DescribeAudioStatResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Overview: 识别结果统计
         :type Overview: :class:`tencentcloud.ams.v20200608.models.Overview`
         :param TrendCount: 识别量统计
@@ -631,7 +717,7 @@ class DescribeBizConfigRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 审核业务类类型
         :type BizType: str
         """
@@ -640,6 +726,13 @@ class DescribeBizConfigRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.BizType = params.get("BizType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBizConfigResponse(AbstractModel):
@@ -648,7 +741,7 @@ class DescribeBizConfigResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 业务类型
         :type BizType: str
         :param BizName: 业务名称
@@ -693,7 +786,7 @@ class DescribeTaskDetailRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 任务ID，创建任务后返回的TaskId字段
         :type TaskId: str
         :param ShowAllSegments: 是否展示所有分片，默认只展示命中规则的分片
@@ -706,6 +799,13 @@ class DescribeTaskDetailRequest(AbstractModel):
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
         self.ShowAllSegments = params.get("ShowAllSegments")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTaskDetailResponse(AbstractModel):
@@ -714,7 +814,7 @@ class DescribeTaskDetailResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TaskId: 任务ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskId: str
@@ -840,7 +940,7 @@ class EvilCount(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: ----非必选，该参数功能暂未对外开放
         :type EvilType: str
         :param Count: 分布类型总量
@@ -853,6 +953,13 @@ class EvilCount(AbstractModel):
     def _deserialize(self, params):
         self.EvilType = params.get("EvilType")
         self.Count = params.get("Count")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class FileOutput(AbstractModel):
@@ -861,7 +968,7 @@ class FileOutput(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Bucket: 存储的Bucket
         :type Bucket: str
         :param Region: Cos Region
@@ -878,6 +985,13 @@ class FileOutput(AbstractModel):
         self.Bucket = params.get("Bucket")
         self.Region = params.get("Region")
         self.ObjectPrefix = params.get("ObjectPrefix")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Filter(AbstractModel):
@@ -886,7 +1000,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 过滤键的名称。
         :type Name: str
         :param Values: 一个或者多个过滤值。
@@ -899,6 +1013,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Filters(AbstractModel):
@@ -907,7 +1028,7 @@ class Filters(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 查询字段：
 策略BizType
 子账号SubUin
@@ -923,6 +1044,13 @@ class Filters(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageResult(AbstractModel):
@@ -931,7 +1059,7 @@ class ImageResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param HitFlag: 违规标志
 0 未命中
 1 命中
@@ -975,6 +1103,13 @@ class ImageResult(AbstractModel):
                 self.Results.append(obj)
         self.Url = params.get("Url")
         self.Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageResultResult(AbstractModel):
@@ -983,7 +1118,7 @@ class ImageResultResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 场景
 Porn 色情
 Sexy 性感
@@ -1044,6 +1179,13 @@ Ad 广告
                 obj = ImageResultsResultDetail()
                 obj._deserialize(item)
                 self.Details.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageResultsResultDetail(AbstractModel):
@@ -1052,7 +1194,7 @@ class ImageResultsResultDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Location: 位置信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Location: list of ImageResultsResultDetailLocation
@@ -1111,6 +1253,13 @@ class ImageResultsResultDetail(AbstractModel):
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageResultsResultDetailLocation(AbstractModel):
@@ -1119,7 +1268,7 @@ class ImageResultsResultDetailLocation(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param X: x坐标
 注意：此字段可能返回 null，表示取不到有效值。
         :type X: float
@@ -1149,6 +1298,13 @@ class ImageResultsResultDetailLocation(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.Rotate = params.get("Rotate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageSegments(AbstractModel):
@@ -1157,7 +1313,7 @@ class ImageSegments(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Result: 画面截帧结果详情
         :type Result: :class:`tencentcloud.ams.v20200608.models.ImageResult`
         :param OffsetTime: 截帧时间。
@@ -1174,6 +1330,13 @@ class ImageSegments(AbstractModel):
             self.Result = ImageResult()
             self.Result._deserialize(params.get("Result"))
         self.OffsetTime = params.get("OffsetTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InputInfo(AbstractModel):
@@ -1182,7 +1345,7 @@ class InputInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 传入的类型可选：URL，COS
 注意：此字段可能返回 null，表示取不到有效值。
         :type Type: str
@@ -1204,6 +1367,13 @@ class InputInfo(AbstractModel):
         if params.get("BucketInfo") is not None:
             self.BucketInfo = BucketInfo()
             self.BucketInfo._deserialize(params.get("BucketInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MediaInfo(AbstractModel):
@@ -1212,7 +1382,7 @@ class MediaInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Codecs: 编码格式
         :type Codecs: str
         :param Duration: 流检测时分片时长
@@ -1238,6 +1408,13 @@ class MediaInfo(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.Thumbnail = params.get("Thumbnail")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MediaModerationConfig(AbstractModel):
@@ -1246,7 +1423,7 @@ class MediaModerationConfig(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AudioFrequency: 音频截帧频率。默认一分钟
         :type AudioFrequency: int
         :param ImageFrequency: 图片取帧频率, 单位（秒/帧），默认 5， 可选 1 ～ 300
@@ -1277,6 +1454,13 @@ class MediaModerationConfig(AbstractModel):
             self.SegmentOutput._deserialize(params.get("SegmentOutput"))
         self.UseOCR = params.get("UseOCR")
         self.UseAudio = params.get("UseAudio")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Overview(AbstractModel):
@@ -1285,7 +1469,7 @@ class Overview(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总调用量
         :type TotalCount: int
         :param TotalHour: 总调用时长
@@ -1322,6 +1506,13 @@ class Overview(AbstractModel):
         self.EvilHour = params.get("EvilHour")
         self.SuspectCount = params.get("SuspectCount")
         self.SuspectHour = params.get("SuspectHour")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StorageInfo(AbstractModel):
@@ -1330,7 +1521,7 @@ class StorageInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Type: 类型 可选：
 URL 资源链接类型
 COS 腾讯云对象存储类型
@@ -1351,6 +1542,13 @@ COS 腾讯云对象存储类型
         if params.get("BucketInfo") is not None:
             self.BucketInfo = BucketInfo()
             self.BucketInfo._deserialize(params.get("BucketInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TaskInput(AbstractModel):
@@ -1359,7 +1557,7 @@ class TaskInput(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DataId: 数据ID
         :type DataId: str
         :param Name: 任务名
@@ -1378,6 +1576,13 @@ class TaskInput(AbstractModel):
         if params.get("Input") is not None:
             self.Input = StorageInfo()
             self.Input._deserialize(params.get("Input"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TaskLabel(AbstractModel):
@@ -1386,7 +1591,7 @@ class TaskLabel(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
 以及令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
@@ -1408,6 +1613,13 @@ class TaskLabel(AbstractModel):
         self.Label = params.get("Label")
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TaskResult(AbstractModel):
@@ -1416,7 +1628,7 @@ class TaskResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DataId: 请求时传入的DataId
 注意：此字段可能返回 null，表示取不到有效值。
         :type DataId: str
@@ -1441,6 +1653,13 @@ class TaskResult(AbstractModel):
         self.TaskId = params.get("TaskId")
         self.Code = params.get("Code")
         self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TrendCount(AbstractModel):
@@ -1449,7 +1668,7 @@ class TrendCount(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 总调用量
         :type TotalCount: int
         :param TotalHour: 总调用时长
@@ -1489,4 +1708,11 @@ class TrendCount(AbstractModel):
         self.EvilHour = params.get("EvilHour")
         self.SuspectCount = params.get("SuspectCount")
         self.SuspectHour = params.get("SuspectHour")
-        self.Date = params.get("Date")
\ No newline at end of file
+        self.Date = params.get("Date")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
